@@ -1,7 +1,7 @@
 #!/bin/sh
 
 # Set Double Commander version
-DC_VER=0.5.8
+DC_VER=0.5.10
 
 # The new package will be saved here
 PACK_DIR=$(pwd)/linux/release
@@ -59,9 +59,8 @@ fi
 rm -rf $BUILD_DC_TMP_DIR
 svn export ../ $BUILD_DC_TMP_DIR
 
-# Save revision number
-mkdir $BUILD_DC_TMP_DIR/.svn
-cp -a ../.svn/entries $BUILD_DC_TMP_DIR/.svn/
+# Update revision number
+linux/update-revision.sh ../ $BUILD_DC_TMP_DIR
 
 # Copy package description file
 cp linux/description-pak $BUILD_DC_TMP_DIR/
