@@ -3,9 +3,9 @@
 # This script updates Double Commander Personal Package Archive (PPA) repository
 
 # Set Double Commander version
-DC_VER=0.5.8
+DC_VER=0.5.10
 # Set Ubuntu series
-DISTRO=( precise quantal raring saucy )
+DISTRO=( precise quantal saucy trusty )
 
 # Temp directory
 DC_TEMP_DIR=/var/tmp/doublecmd-$(date +%y.%m.%d)
@@ -13,27 +13,18 @@ DC_TEMP_DIR=/var/tmp/doublecmd-$(date +%y.%m.%d)
 DC_SOURCE_DIR=$DC_TEMP_DIR/doublecmd-$DC_VER
 # Directory for DC help
 DC_HELP_DIR=$DC_TEMP_DIR/doublecmd-help-$DC_VER
-# DC revision number
-DC_REVISION=$(svnversion ../../ | sed -e 's/\([0-9]*\).*/\1/')
 
 # Recreate temp directory
 rm -rf $DC_TEMP_DIR
 mkdir -p $DC_TEMP_DIR
 
-update_revision()
-{
-  # Update dcrevision.inc
-  echo "// Created by Svn2RevisionInc"      >  $DC_SOURCE_DIR/src/dcrevision.inc
-  echo "const dcRevision = '$DC_REVISION';" >> $DC_SOURCE_DIR/src/dcrevision.inc
-}
-
 update_doublecmd()
 {
   # Export from SVN
   svn export ../../ $DC_SOURCE_DIR
 
   # Save revision number
-  update_revision
+  DC_REVISION=`$(pwd)/update-revision.sh ../../ $DC_SOURCE_DIR`
 
   # Remove help files
   rm -rf $DC_SOURCE_DIR/doc/en
@@ -54,7 +45,7 @@ update_doublecmd()
   do
     # Update changelog file
     pushd $DC_SOURCE_DIR/debian
-    dch -m -D $DIST -v $DC_VER-0+svn$DC_REVISION~$DIST "Update to revision $DC_REVISION"
+    dch -D $DIST -v $DC_VER-0+svn$DC_REVISION~$DIST "Non-maintainer upload (revision $DC_REVISION)"
     popd
 
     # Create archive with source code
@@ -75,7 +66,7 @@ update_doublecmd_svn()
   svn export ../../ $DC_SOURCE_DIR
 
   # Save revision number
-  update_revision
+  DC_REVISION=`$(pwd)/update-revision.sh ../../ $DC_SOURCE_DIR`
 
   # Remove help files
   rm -rf $DC_SOURCE_DIR/doc/en
@@ -92,7 +83,7 @@ update_doublecmd_svn()
   do
     # Update changelog file
     pushd $DC_SOURCE_DIR/debian
-    dch -m -D $DIST -v $DC_VER-0+svn$DC_REVISION~$DIST "Update to revision $DC_REVISION"
+    dch -D $DIST -v $DC_VER-0+svn$DC_REVISION~$DIST "Non-maintainer upload (revision $DC_REVISION)"
     popd
 
     # Create archive with source code
